@@ -24,7 +24,7 @@ double dnull_entry();
 void subgradeffw(double y[], double g[]);
 void null_entry();
 
-double solvoptweights(int npoints, double *y_in, double sigma_ralg2(),void subgrad_ralg2(),double *opt_out, double fun() ,void fun2(), double *parameters );
+double solvoptweights(int npoints, double *y_in, double sigma_ralg2(),void subgrad_ralg2(),double *opt_out, double fun() ,void fun2() );
 
 void renormalise( double *y );
 
@@ -35,7 +35,6 @@ void logconestw ( double *y_in,
 		  double *weights_in, 
 		  double *opt_out, 
 		  double *sigmavalue_out, 
-		  double *parameters, 
 		  double *Jtol_in,
 		  char **chopts_in,
 		  int *nouter_in)
@@ -51,7 +50,7 @@ void logconestw ( double *y_in,
   chopts = *chopts_in;
 
   /* Use the solvoptweights */
-  *sigmavalue_out=solvoptweights(truepoints,y_in,&sigmaeffw,&subgradeffw,opt_out,&dnull_entry,&null_entry,parameters);
+  *sigmavalue_out=solvoptweights(truepoints,y_in,&sigmaeffw,&subgradeffw,opt_out,&dnull_entry,&null_entry);
   renormalise(y_in);
   /*That's all!*/
 }
